@@ -74,7 +74,7 @@ consume more CPU than configured cgroup-limit.
 
 def wait_for_idle_cpus(required, *, max_concurrent=None, fixed_delay=0.2, inertia=0.7):
     workers = WorkersRunning()
-    cpu_poll_interval = MovingAverage(1, 0.7)
+    cpu_wait_time = MovingAverage(1, 0.7)
 
     process = Process()
 
@@ -112,14 +112,14 @@ def wait_for_idle_cpus(required, *, max_concurrent=None, fixed_delay=0.2, inerti
         if cpu_quota:
             cpu_used = InertialTimeDerivate(cpu_used_in_process, cpu_count(), inertia)
 
-        cpu_poll_interval = max(CPU_IDLE_POLL_MIN_INTERVAL, min(cpu_poll_interval.value, CPU_IDLE_POLL_MAX_INTERVAL))
+        cpu_poll_interval = max(CPU_IDLE_POLL_MIN_INTERVAL, min(cpu_wait_time.value / CPU_IDLE_POLL_DIVISOR, CPU_IDLE_POLL_MAX_INTERVAL))
         while workers.count > 0 and not halt():
             if (
                 workers.count < max_concurrent
                 and idle.update() >= required
                 and (cpu_quota is None or cpu_used.update() <= cpu_quota)
             ):
-                cpu_poll_interval.update((time() - start_time) / CPU_IDLE_POLL_DIVISOR)
+                cpu_wait_time.update(time() - start_time)
                 break
 
             sleep(cpu_poll_interval)
